@@ -879,7 +879,7 @@ class World:
             caption=name, resizable=True)
         self.window.unknown_key_pressed = self.__build_key_function
 
-    def build_key_pressed(self):
+    def build_key_pressed(self, world):
         print("b pressed.")
 
     def __build_key_function(self, symbol):
@@ -962,7 +962,7 @@ def main():
     
     # Eine Funktion, die beim Drücken der B-Taste aufgerufen werden soll
     def b_key_pressed(world:World):
-        print("B pressed. Player at", world.play_position())
+        print("B pressed. Player at", world.player_position())
         
     # Erstellen einer neuen Welt
     world = World()
